@@ -11,7 +11,6 @@ import glob
 import os
 import sys
 
-import ecfas.cmems_datasets as dsets
 import numpy as np
 import pandas as pd
 import xarray as xr
@@ -74,7 +73,7 @@ def run_checks(outdir, baselinedir, region, start_time):
     print('Comparing PROCESSED timeseries...\n')
     ok2 = True
     if region != 'ARC_ocean':
-        labelproc = ['b%s_%s_%s' % (t0.strftime('%Y%m%d%H%M%S'), tstarti.strftime('%Y%m%d'), (tstarti + datetime.timedelta(days=1)).strftime('%Y%m%d')) for tstarti in pd.date_range(start=pred_start, end=pred_end, freq='1D', closed='left')]
+        labelproc = ['b%s_%s_%s' % (t0.strftime('%Y%m%d%H%M%S'), tstarti.strftime('%Y%m%d'), (tstarti + datetime.timedelta(days=1)).strftime('%Y%m%d')) for tstarti in pd.date_range(start=pred_start, end=pred_end, freq='1D', inclusive='left')]
 
         for ilab in labelproc:
             print('Checking daily file %s\n' % ilab)
@@ -91,7 +90,7 @@ def run_checks(outdir, baselinedir, region, start_time):
             refdata = xr.open_dataset(ref_file, decode_times=False)
             twindata = xr.open_dataset(baseline_file, decode_times=False)
 
-            for vari in twindata.variables:
+            for vari in twindata.data_vars:
                 # skip non-numeric data (e.g. station names, coordinates will tell us if this is ok)
                 if refdata[vari].dtype in ['float32', 'int64']:
                     checkdata = np.allclose(refdata[vari].values, twindata[vari].values, equal_nan=True, atol=0.01)
@@ -125,6 +124,8 @@ def main():
     parser.add_argument('-t', '--t0', metavar='<YYmmdd_HHMMSS>', required=True, help='Start time t0 in the format YYmmdd_HHMMSS')
 
     args = parser.parse_args()
+    #args = parser.parse_args(['-o','/homelocal2/mirazoki/ECFAS/data/CMEMS/test_workflow_Sept2022_merge','-b','/home/mirazoki/ECFAS/01_task1/operational/ecfas_merge/ecfas/baselines/',
+    #                           '-r','MED','-t','20220125_000000'])
 
     ok = run_checks(args.outputs, args.baselines, args.region, args.t0)
     # If any of the checks fail, exit with error flag, which will be picked up by test framework as a fail
